@@ -6,8 +6,9 @@
 package IO::Async::Connector;
 
 use strict;
+use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 
 use POSIX qw( EINPROGRESS );
 use Socket qw( SOL_SOCKET SO_ERROR );
@@ -355,4 +356,4 @@ __END__
 
 =head1 AUTHOR
 
-Paul Evans E<lt>leonerd@leonerd.org.ukE<gt>
+Paul Evans <leonerd@leonerd.org.uk>
