@@ -8,7 +8,7 @@ package IO::Async::Loop::IO_Poll;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use base qw( IO::Async::Loop );
 
@@ -273,4 +273,4 @@ __END__
 
 =head1 AUTHOR
 
-Paul Evans E<lt>leonerd@leonerd.org.ukE<gt>
+Paul Evans <leonerd@leonerd.org.uk>
