@@ -6,8 +6,9 @@
 package IO::Async::Loop::Select;
 
 use strict;
+use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 
 use base qw( IO::Async::Loop );
 
@@ -260,4 +261,4 @@ L<IO::Select> - OO interface to select system call
 
 =head1 AUTHOR
 
-Paul Evans E<lt>leonerd@leonerd.org.ukE<gt>
+Paul Evans <leonerd@leonerd.org.uk>
